.. vbvarsel documentation master file, created by
   sphinx-quickstart on Wed May  5 22:45:36 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to vbvarsel's documentation!
==========================================================

.. toctree::
  :maxdepth: 2
  :caption: Contents:

  usage
  contributing

.. Check out the :doc:`usage` section for further information, including how to
.. :ref:`install <installation>` the project.

Indices and tables
==================



* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
